@@ -5,8 +5,8 @@
 #' The subsample size m can either be chosen directly or estimated with [estimate.m()].
 #'
 #' @param data The data to be bootstrapped. If it is multidimensional, each row is considered as one observation passed to the \code{statistic}.
-#' @param statistic A function returing the statistic of interest. It must take two arguments. The first argument passed will be the original data, the second
-#' will be a vector of indicies. Any further arguments can be passed through the \code{...} argument.
+#' @param statistic A function returning the statistic of interest. It must take two arguments. The first argument passed will be the original data, the second
+#' will be a vector of indices. Any further arguments can be passed through the \code{...} argument.
 #' @param R The number of bootstrap replicates.
 #' @param m The subsampling size.
 #' @param replace Whether sampling should be done with replacement or without replacement (the default).
@@ -67,7 +67,7 @@ mboot <- function(data, statistic, m, R = 1000, replace = FALSE, ...) {
 #' m-Out-of-n Bootstrap Confidence Intervals
 #'
 #' Estimates the confidence interval using the methods provided by \code{types}.
-#' \code{tau} must be a function that calculates teh scaling factor
+#' \code{tau} must be a function that calculates the scaling factor
 #' tau(n) for a given n. If \code{tau} is not provided, it is estimated
 #' with \code{estimate.tau} using the default settings of this function.
 #'
@@ -89,7 +89,7 @@ mboot <- function(data, statistic, m, R = 1000, replace = FALSE, ...) {
 #' as \code{tau} argument. For the type \code{sherman}, \code{tau} is not
 #' needed and its value is ignored.
 #' 
-#' The following methods to compute teh confidence intervals are supported
+#' The following methods to compute the confidence intervals are supported
 #' through the parameter \code{type}:
 #' 
 #' \describe{\item{basic:}{
@@ -100,14 +100,22 @@ mboot <- function(data, statistic, m, R = 1000, replace = FALSE, ...) {
 #' This method does not scale the interval with tau(m)/tau(n) and thus is too wide. To avoid over-coverage, this is compensated by centering it randomly around the point estimators of one of the m-out-of-n bootstrap samples. Although this results on average in the nominal coverage probability, the interval is less accurate than the other intervals and should be used only as a last resort if the scaling factor tau is neither known, nor estimatable.}}
 #'
 #' @examples
+#' # statistic for univariate data: maximum
 #' data <- runif(1000)
 #' estimate.max <- function(data, indices) {return(max(data[indices]))}
 #' tau <- function(n){n} # convergence rate (usually sqrt(n), but n for max) 
 #' boot.out <- mboot(data, estimate.max, R = 1000, m = 2*sqrt(NROW(data)), replace = FALSE)
-#' cis <- mboot.ci(boot.out, 0.95, tau, c("all"))
-#' ci.basic <- cis$basic
-#' print(ci.basic)
+#' cis <- mboot.ci(boot.out, conf=0.95, tau=tau, types=c("basic","norm"))
+#' print(cis$basic)
 #'
+#' # statistic for multivariate data: correlation
+#' data <- data.frame(x = runif(1000))
+#' data$y <- data$x + runif(1000)
+#' estimate.cor <- function(data, indices) {return(cor(data$x[indices],data$y[indices]))}
+#' boot.out <- mboot(data, estimate.cor, R = 1000, m = 2*sqrt(NROW(data)), replace = FALSE)
+#' cis <- mboot.ci(boot.out, conf=0.95, tau=sqrt, types=c("basic","norm"))
+#' print(cis$basic)
+#' 
 #' @importFrom stats quantile
 #' @importFrom stats var
 #' @importFrom stats ecdf
@@ -119,7 +127,7 @@ mboot <- function(data, statistic, m, R = 1000, replace = FALSE, ...) {
 #' based on subsamples under minimal assumptions. \emph{The Annals of Statistics}, 22(4):2031-2050, \doi{10.1214/aos/1176325770}
 #' @references Sherman M. and Carlstein E. (2004) Confidence intervals based on estimators with unknown rates of convergence.
 #' \emph{Computional statistics & data analysis}, 46(1):123-136.
-#' @references Dalitz C. and Lögler M. (2024) moonboot: An R Package Implementing m-out-of-n Bootstrap Methods \doi{10.48550/arXiv.2412.05032}
+#' @references Dalitz C. and Lögler F. (2025) moonboot: An R Package Implementing m-out-of-n Bootstrap Methods \doi{10.32614/RJ-2025-031}
 #' @keywords ~htest
 #' @export
 mboot.ci <- function(boot.out, conf = 0.95, tau = NULL, types = "all", ...) {
@@ -133,9 +141,16 @@ mboot.ci <- function(boot.out, conf = 0.95, tau = NULL, types = "all", ...) {
 
   if ("basic" %in% types | "norm" %in% types) { # tau is not needed if sherman is the only type
     if (is.null(tau))
-      tau <- estimate.tau(boot.out$data, boot.out$statistic, R = 1000, replace = FALSE, ...)
+      tau <- estimate.tau(boot.out$data, boot.out$statistic, R = 1000, replace = boot.out$replace, ...)
     if (!is.function(tau))
       stop("tau must be a function")
+    # plausi check: tau(n) -> infty for n -> infty?
+    if (tau(20) <= tau(10)) {
+      warning("tau(n) does not increase in n => m-out-of-n bootstrap might not work")
+    } else if (tau(20)/tau(10) < 2^0.05) {
+      warning("suspicious slow increase of tau(n) => m-out-of-n bootstrap might not work")
+    }
+
   }
   alpha <- 1 - conf
 
@@ -176,7 +191,8 @@ mboot.ci <- function(boot.out, conf = 0.95, tau = NULL, types = "all", ...) {
 #' It is also possible to pass parameters to the statistic using '...'.
 #'
 #' @param data The data to be bootstrapped.
-#' @param statistic The estimator of the parameter.
+#' @param statistic A function returning the statistic of interest. It must take two arguments. The first argument passed will be the original data, the second
+#' will be a vector of indices. Any further arguments can be passed through the \code{...} argument.
 #' @param tau The convergence rate.
 #' @param R The amount of bootstrap replicates. Must be a positive integer.
 #' @param method The method to be used, one of \code{c("goetze","bickel","politis", "sherman")}.
@@ -224,15 +240,15 @@ mboot.ci <- function(boot.out, conf = 0.95, tau = NULL, types = "all", ...) {
 #' It tries to estimate the coverage error of different subsampling sizes and chooses the subsampling
 #' size with the lowest one.
 #' As estimating the coverage error is highly computationally intensive, it is not practical to try all m values.
-#' Therefore, the \code{beta} parameter can be used to control which \code{m} values are tried. The values
-#' are then calculated by \code{ms = n^beta}. The default value is a sequence between 0.3 and 0.9 out of 15 values.
+#' Therefore, the \code{gamma} parameter can be used to control which \code{m} values are tried. The values
+#' are then calculated by \code{ms = n^gamma}. The default value is a sequence between 0.3 and 0.9 out of 15 values.
 #' This parameter can be set using \code{params}.}}
 #'
 #' @examples
 #' data <- runif(1000)
 #' estimate.max <- function(data, indices) {return(max(data[indices]))}
 #' tau <- function(n){n} # convergence rate (usually sqrt(n), but n for max) 
-#' choosen.m <- estimate.m(data, estimate.max, tau, R = 1000, method = "bickel")
+#' choosen.m <- estimate.m(data, estimate.max, tau=tau, R = 1000, method = "bickel")
 #' print(choosen.m)
 #'
 #'
@@ -253,7 +269,7 @@ mboot.ci <- function(boot.out, conf = 0.95, tau = NULL, types = "all", ...) {
 
 estimate.m <- function(data, statistic, tau = NULL, R = 1000, replace = FALSE, min.m = 3, method = "bickel", params = NULL, ...) {
   if (is.null(tau) & method != "sherman") {
-    tau <- estimate.tau(data, statistic, R = 1000, replace = FALSE, ...)
+    tau <- estimate.tau(data, statistic, R = 1000, replace = replace, ...)
   }
 
   if ("goetze" == method) {
@@ -450,19 +466,20 @@ estimate.m.politis <- function(data, statistic, tau, R, replace = FALSE, min.m,
 #' and returns it as a function of the form \code{tau_n = n^a}, where \code{n} is the input parameter.
 #'
 #' @param data The data to be bootstrapped.
-#' @param statistic The estimator of the parameter.
+#' @param statistic A function returning the statistic of interest. It must take two arguments. The first argument passed will be the original data, the second
+#' will be a vector of indices. Any further arguments can be passed through the \code{...} argument.
 #' @param R Amount of bootstrap replicates used to estimate tau.
 #' @param replace If sampling should be done with replacement.
 #' @param min.m Minimal subsampling size used to estimate tau. Should be set to the minimum size for which the statistic makes sense.
-#' @param beta The tested subsample sizes m are \code{n^beta}.
+#' @param gamma The tested subsample sizes m are \code{n^gamma}.
 #' @param method Method to estimate tau, can be one of \code{c("variance", "quantile")}.
 #' @param ... Additional parameters to be passed to the \code{mboot} function.
 #'
 #' @return A function for the square root of the convergence rate of the variance, i.e., \code{f(n) = tau_n}. This function can directly be passed to \code{mboot.ci}.
 #'
 #' @details There are two methods to choose from, \code{variance} and \code{quantile}.
-#' The provided \code{beta} values are used to select subsample sizes \code{m} by using \code{ms = n^beta}.
-#' Note that the choice of the \code{beta} values can impact the accuracy of the estimated \code{tau} (Dalitz & Lögler, 2024).
+#' The provided \code{gamma} values are used to select subsample sizes \code{m} by using \code{ms = n^gamma}.
+#' Note that the choice of the \code{gamma} values can impact the accuracy of the estimated \code{tau} (Dalitz & Lögler, 2024).
 #' For each selected subsample size \code{m} a bootstrap with \code{R} replications is performed.
 #' The method 'variance' then fits a linear function to log(variance) of the bootstrap statistics as function of log(m).
 #' The method 'quantile' averages over multiple quantile ranges Q and fits a linear function to log(Q) as a function of log(m).
@@ -473,7 +490,7 @@ estimate.m.politis <- function(data, statistic, tau, R, replace = FALSE, min.m,
 #' estimate.max <- function(data, indices) {return(max(data[indices]))}
 #' estimated.tau <- estimate.tau(data, estimate.max)
 #' boot.out <- mboot(data, estimate.max, R = 1000, m = 2*sqrt(NROW(data)), replace = FALSE)
-#' cis <- mboot.ci(boot.out, 0.95, estimated.tau, c("all"))
+#' cis <- mboot.ci(boot.out, conf=0.95, tau=estimated.tau, types=c("all"))
 #' ci.basic <- cis$basic
 #' print(ci.basic)
 #'
@@ -483,27 +500,27 @@ estimate.m.politis <- function(data, statistic, tau, R, replace = FALSE, min.m,
 #' \emph{Journal of the American Statistical Association}, 94(446):568-579.
 #' @references Politis D.N. et al. (1999)
 #' \emph{Subsampling}, Springer, New York.
-#' @references Dalitz, C, and Lögler, F. (2024)
+#' @references Dalitz, C, and Lögler, F. (2025)
 #' \emph{moonboot: An R Package Implementing m-out-of-n Bootstrap Methods}.
-#' \doi{10.48550/arXiv.2412.05032}
+#' \doi{10.32614/RJ-2025-031}
 #'
 #' @importFrom stats lm
 #' @importFrom stats coef
 #' @export
-estimate.tau <- function(data, statistic, R = 1000, replace = FALSE, min.m = 3, beta = seq(0.2, 0.7, length.out = 5), method = "variance", ...) {
+estimate.tau <- function(data, statistic, R = 1000, replace = FALSE, min.m = 3, gamma = seq(0.2, 0.7, length.out = 5), method = "variance", ...) {
   if ("variance" == method) {
-    return(estimate.tau.variance(data, statistic, R = R, replace = replace, min.m = min.m, beta = beta, ...))
+    return(estimate.tau.variance(data, statistic, R = R, replace = replace, min.m = min.m, gamma = gamma, ...))
   }else if ("quantile" == method) {
-    return(estimate.tau.quantile(data, statistic, R = R, replace = replace, min.m = min.m, bs = beta, ...))
+    return(estimate.tau.quantile(data, statistic, R = R, replace = replace, min.m = min.m, gamma = gamma, ...))
   }
 }
 
 # Estimates tau using the variance method suggested by Bertail et al. (1999)
-estimate.tau.variance <- function(data, statistic, R = 1000, replace = FALSE, min.m, beta = seq(0.2, 0.7, length.out = 5), ...) {
+estimate.tau.variance <- function(data, statistic, R = 1000, replace = FALSE, min.m, gamma = seq(0.2, 0.7, length.out = 5), ...) {
   n <- NROW(data)
-  beta <- pmin(1, pmax(0, beta)) # force them to be in bounds
+  gamma <- pmin(1, pmax(0, gamma)) # force them to be in bounds
   # b from the paper is called m for consistency with the rest of the code
-  m <- n^beta
+  m <- n^gamma
   m <- m[m >= min.m]
   m.boots <- lapply(m, function(m) mboot(data, statistic, R = R, m = ceiling(m), replace = replace, ...))
   V.m <- lapply(m.boots, function(boot) var(boot$t))
@@ -516,10 +533,9 @@ estimate.tau.variance <- function(data, statistic, R = 1000, replace = FALSE, mi
 }
 
 # Estimate tau using the method suggested by Polits et al. (1999).
-estimate.tau.quantile <- function(data, statistic, R = 1000, replace = FALSE, min.m, bs, ...) {
+estimate.tau.quantile <- function(data, statistic, R = 1000, replace = FALSE, min.m, gamma = seq(0.2, 0.7, length.out=5), ...) {
   n <- NROW(data)
   J <- 5
-  I <- 5
   j <- seq(1, J, by = 1)
   t <- numeric(2 * J)
 
@@ -529,9 +545,7 @@ estimate.tau.quantile <- function(data, statistic, R = 1000, replace = FALSE, mi
     t[2 * i] <- seq.one[i]
     t[2 * i - 1] <- seq.two[i]
   }
-  if (!hasArg(bs))
-    bs <- seq(0.2, 0.7, length.out = I)
-  ms <- floor(n^bs)
+  ms <- floor(n^gamma)
   ms <- unique(ms)
   ms <- ms[ms >= min.m & ms <= n]
   I <- length(ms)
